Efficient approximate leave-one-out cross-validation (LOO)
Source:R/posterior-methods.R
loo.brmcoda.RdPerform approximate leave-one-out cross-validation based
on the posterior likelihood using the loo package.
For more details see loo.
Arguments
- x
A
brmcodaobject.- ...
More
brmsfitobjects or further arguments passed to the underlying post-processing functions. In particular, seeprepare_predictionsfor further supported arguments.
Value
If just one object is provided, an object of class loo.
If multiple objects are provided, an object of class loolist.