Indices from a (dataset of) Multilevel Composition(s) (deprecated.)
compilr(...)A complr object with at least the following elements.
compA vector of class acomp representing one closed composition
or a matrix of class acomp representing multiple closed compositions each in one row.
between_compA vector of class acomp representing one closed between-person composition
or a matrix of class acomp representing multiple closed between-person compositions each in one row.
within_compA vector of class acomp representing one closed within-person composition
or a matrix of class acomp representing multiple closed within-person compositions each in one row.
logratioLog ratio transform of composition.
between_logratioLog ratio transform of between-person composition.
within_logratioLog ratio transform of within-person composition.
dataThe user's dataset or imputed dataset if the input data contains zeros.
transformType of transform applied on compositional data.
partsNames of compositional variables.
idvarName of the variable containing IDs.
totalTotal amount to which the compositions is closed.
arguments passed to complr.
complr